Module dom

Module dom 

Statics

PROLOG
TAGS_BY_CLASS
TAGS_BY_ID
TAGS_BY_NAME

Functions

delete
get_all_elements
get_element_by_id
if elements is None, it searches the entire DOM.
get_element_by_tag_name
if elements is None, it searches the entire DOM. It returns the first element with the given tag_name, if exists.
get_elements_by_class_name
if elements is None, it searches the entire DOM.
get_elements_by_tag_name
if elements is None, it searches the entire DOM.
get_ids
if elements is None, it searches the entire DOM.
get_root
some_checks
It checks whether
to_string